bayespy.inference.vmp.nodes.categorical.CategoricalDistribution.compute_cgf_from_parents
========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. automethod:: CategoricalDistribution.compute_cgf_from_parents